===========
Django Slick
===========

**Slick responsive theme for the Django admin interface**.


License
=======

* Django Slick is licensed under `Creative Commons Attribution-NonCommercial 3.0 <http://creativecommons.org/licenses/by-nc/3.0/>`_ license.
